@@ -477,6 +477,8 @@ class BaseContour(
         Subclasses may override this method.
         """
         points = list(self.points)
+        if not points:
+            return []
         segments = [[]]
         lastWasOffCurve = False
         firstIsMove = points[0].type == "move"
@@ -490,7 +492,7 @@ class BaseContour(
         if lastWasOffCurve and firstIsMove:
             # ignore trailing off curves
             del segments[-1]
-        if lastWasOffCurve and not firstIsMove:
+        if lastWasOffCurve and not firstIsMove and len(segments) > 1:
             segment = segments.pop(-1)
             segment.extend(segments[0])
             del segments[0]
@@ -586,7 +588,11 @@ class BaseContour(
         onCurve = points[-1]
         offCurve = points[:-1]
         segments = self.segments
-        ptCount = sum([len(segments[s].points) for s in range(index)]) + 1
+        addPointCount = 1
+        if self.open:
+            index += 1
+            addPointCount = 0
+        ptCount = sum([len(segments[s].points) for s in range(index)]) + addPointCount
         self.insertPoint(ptCount, onCurve, type=type, smooth=smooth)
         for offCurvePoint in reversed(offCurve):
             self.insertPoint(ptCount, offCurvePoint, type="offcurve")
